'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded = ["segments", "onChangeSegment"];
/**if no default property is set, the default selected segment is automatically the first encountered  */

var SegmentedControl = function SegmentedControl(_ref) {
  var _segments$find$value, _segments$find;

  var segments = _ref.segments,
      onChangeSegment = _ref.onChangeSegment,
      props = _objectWithoutPropertiesLoose(_ref, _excluded);

  React.useEffect(function () {
    var uniqueKeys = new Set(segments.map(function (_ref2) {
      var value = _ref2.value;
      return value;
    }));

    if (uniqueKeys.size !== segments.length) {
      throw new Error('Segments must have unique values');
    }
  }, [segments]);

  var _useState = React.useState((_segments$find$value = (_segments$find = segments.find(function (s) {
    return s["default"];
  })) == null ? void 0 : _segments$find.value) != null ? _segments$find$value : segments[0].value),
      selectedSegment = _useState[0],
      setSelectedSegment = _useState[1];

  var onChange = function onChange(selectedSegment) {
    setSelectedSegment(selectedSegment);
    onChangeSegment(selectedSegment);
  };

  var renderSegments = function renderSegments() {
    return segments.map(function (segment) {
      if (segment.value === selectedSegment) {
        var _segment$label;

        return React__default.createElement("li", {
          key: segment.value,
          className: "selected"
        }, (_segment$label = segment == null ? void 0 : segment.label) != null ? _segment$label : '');
      }

      if (segment.disabled) {
        var _segment$label2;

        return React__default.createElement("li", {
          key: segment.value,
          className: "disabled"
        }, (_segment$label2 = segment == null ? void 0 : segment.label) != null ? _segment$label2 : '');
      }

      return React__default.createElement("li", {
        key: segment.value,
        onClick: function onClick() {
          return onChange(segment.value);
        }
      }, segment.label);
    });
  };

  return React__default.createElement("div", Object.assign({
    className: "segmented-control-container"
  }, props), React__default.createElement("ul", null, renderSegments()));
};

exports.SegmentedControl = SegmentedControl;
//# sourceMappingURL=ios-segmented-control-react.cjs.development.js.map
